AbstractApi class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
String serviceName, RequestMethod method, String path, ContentTypeEnum requestContentType, ContentTypeEnum responseContentType, bool? login, dynamic data) → Future -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- requestHandler ↔ AbstractRequestHandler?
-
getter/setter pair
- responseHandler ↔ AbstractResponseHandler?
-
getter/setter pair