RequestHandler class
- Inheritance
-
- Object
- AbstractRequestHandler
- RequestHandler
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
String serviceName, RequestMethod method, String path, ContentTypeEnum requestContentType, ContentTypeEnum responseContentType, bool? login, dynamic data) → Future< Response> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited